@@ -78,7 +78,7 @@ Perl_ck_warner(pTHX_ U32 err, const char* pat, ...)
 #define PERL_VERSION_GE(r,v,s) \
 	(PERL_DECIMAL_VERSION >= PERL_VERSION_DECIMAL(r,v,s))
 
-#define ISA_VERSION_OBJ(v,c) (SvROK(v) && sv_derived_from(v,c))
+#define ISA_CLASS_OBJ(v,c) (sv_isobject(v) && sv_derived_from(v,c))
 
 #if PERL_VERSION_GE(5,9,0)
 
